@@ -12,12 +12,12 @@ our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 our @ISA = 'Regexp';
 
 BEGIN {
-    our $VERSION = '0.024'; # VERSION
+    our $VERSION = '0.025'; # VERSION
     XSLoader::load __PACKAGE__, $VERSION;
 }
 
 {
-    no strict 'subs';
+    no strict 'subs';                     ## no critic
     our $RE_SYNTAX_AWK                    = RE_SYNTAX_AWK;
     our $RE_SYNTAX_ED                     = RE_SYNTAX_ED;
     our $RE_SYNTAX_EGREP                  = RE_SYNTAX_EGREP;
@@ -102,7 +102,7 @@ re::engine::GNU - GNU Regular Expression Engine
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
@@ -357,10 +357,18 @@ L<GNU Gnulib Regular expressions|https://www.gnu.org/software/gnulib/manual/html
 
 L<perlre>
 
+=for Pod::Coverage ENGINE RE_SYNTAX_AWK RE_SYNTAX_ED RE_SYNTAX_EGREP RE_SYNTAX_EMACS RE_SYNTAX_GNU_AWK RE_SYNTAX_GREP RE_SYNTAX_POSIX_AWK RE_SYNTAX_POSIX_BASIC RE_SYNTAX_POSIX_EGREP RE_SYNTAX_POSIX_EXTENDED RE_SYNTAX_POSIX_MINIMAL_BASIC RE_SYNTAX_POSIX_MINIMAL_EXTENDED RE_SYNTAX_SED RE_BACKSLASH_ESCAPE_IN_LISTS RE_BK_PLUS_QM RE_CHAR_CLASSES RE_CONTEXT_INDEP_ANCHORS RE_CONTEXT_INDEP_OPS RE_CONTEXT_INVALID_OPS RE_DOT_NEWLINE RE_DOT_NOT_NULL RE_HAT_LISTS_NOT_NEWLINE RE_INTERVALS RE_LIMITED_OPS RE_NEWLINE_ALT RE_NO_BK_BRACES RE_NO_BK_PARENS RE_NO_BK_REFS RE_NO_BK_VBAR RE_NO_EMPTY_RANGES RE_UNMATCHED_RIGHT_PAREN_ORD RE_NO_POSIX_BACKTRACKING RE_NO_GNU_OPS RE_DEBUG RE_INVALID_INTERVAL_ORD RE_ICASE RE_CARET_ANCHORS_HERE RE_CONTEXT_INVALID_DUP RE_NO_SUB
+
 =head1 AUTHOR
 
 Jean-Damien Durand <jeandamiendurand@free.fr>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Yves Orton
+
+Yves Orton <demerphq@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Jean-Damien Durand.
